@@ -35,7 +35,7 @@ class AutoEmbedPaginator(object):
                     for reaction in msg.reactions:
                         if reaction.message.author.id == self.bot.user.id:
                             await msg.remove_reaction(str(reaction.emoji), reaction.message.author)
-                    return
+                    return msg
                     break
             else:
                 reaction, user = await self.bot.wait_for("reaction_add",check=check)
@@ -59,7 +59,7 @@ class AutoEmbedPaginator(object):
                 for reaction in msg.reactions:
                     if reaction.message.author.id == self.bot.user.id:
                         await msg.remove_reaction(str(reaction.emoji), reaction.message.author)
-                return
+                return msg
                 break
             elif str(reaction.emoji) == self.control_emojis[3]:
                 self.current_page = self.current_page + 1
@@ -116,7 +116,7 @@ class CustomEmbedPaginator(object):
         self.embeds = embeds
         if not send_to:
             send_to = self.ctx
-        wait_for = ctx.author if send_to == self.ctx else send_to
+        wait_for = self.ctx.author if send_to == self.ctx else send_to
         if self.auto_footer:
             self.embeds[0].set_footer(text=f'({self.current_page+1}/{len(self.embeds)})')
         msg = await send_to.send(embed=self.embeds[0])
@@ -131,10 +131,10 @@ class CustomEmbedPaginator(object):
                     reaction, user = await self.bot.wait_for("reaction_add",check=check, timeout=self.timeout)
                 except asyncio.TimeoutError:
                     for reaction in msg.reactions:
-                        if reaction.message.author.id == self.bot.user.id:
-                            await msg.remove_reaction(str(reaction.emoji), reaction.message.author)
+                        if reaction.message.author.id == self.bot.user.id and self.remove_reactions:
+                 	           await msg.remove_reaction(str(reaction.emoji), reaction.message.author)
                     self.current_page = 0
-                    return
+                    return msg
                     break
             else:
                 reaction, user = await self.bot.wait_for("reaction_add",check=check)
@@ -175,14 +175,14 @@ class CustomEmbedPaginator(object):
                     elif cmd.lower() == "delete":
                         self.current_page = 0
                         await msg.delete()
-                        return
+                        return msg
                         break
                     elif cmd.lower() == "clear" or cmd.lower() == "lock":
                         self.current_page = 0
                         for reaction in msg.reactions:
                             if reaction.message.author.id == self.bot.user.id:
                                 await msg.remove_reaction(str(reaction.emoji), reaction.message.author)
-                        return
+                        return msg
                         break
                     elif cmd.startswith("page"):
                         shit = cmd.split()
